@@ -1,7 +1,7 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.23"
+__version__ = "1.24"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -32,9 +32,17 @@ import numpy as np
 from functools import wraps
 import time
 
+from os import PathLike
+from typing import Iterator, Union, Iterable
+
+from pathlib import Path, PurePosixPath
+
 log=logging.getLogger(__name__)
 log.addHandler(NullHandler())
 
+StrOrPath=Union[str, PathLike[str]]
+StrOrPathList=Union[str, PathLike[str], Iterable[str], Iterable[PathLike[str]]]
+
 def xlsx_to_csv(filename="",sheet="",newfilename="",separator=""):
     """Funcion que mediante openpyxnl convierne un xlsx a csv(usar Pandas).
 
@@ -73,13 +81,16 @@ def xlsx_to_csv(filename="",sheet="",newfilename="",separator=""):
 
     return
 
-def upload_file_sftp(filename, destine_path="", credentials={}):
+def upload_file_sftp(filename:StrOrPathList, 
+                     destine_path:StrOrPath, 
+                     credentials={}):
     """Funcion que sube archivos a un SFTP
 
     Args:
-        filename (list, optional): Nombre de archivo(acepta comodines unix * ?) o lista de archivos. Defaults to [].
-        destine_path (str, optional): Ruta destino remoto. Defaults to {}.
-        recursive (bool, optional): Flag que permite crear directorios recursivamente. Defaults to False.
+        filename (StrOrPathList): Nombre de archivo(acepta comodines unix * ?) 
+                                  o lista de archivos. Defaults to [].
+        destine_path (StrOrPath): Ruta destino remoto.
+        credentials (dict, optional): Diccionario credenciales. Defaults to {}.
     """
     import paramiko
 
@@ -99,49 +110,62 @@ def upload_file_sftp(filename, destine_path="", credentials={}):
         with paramiko.SFTPClient.from_transport(transport) as server:
             server.get_channel().settimeout(100000.0)
 
-            if type(destine_path) != str:
+            try:
+                destine_path = PurePosixPath(destine_path)
+            except:
                 raise Exception("Destino incorrecto")
             
-            if str(destine_path) != "":    
+            if str(destine_path) != ".":    
                 log.debug("Ubicandose en ruta remota: " + destine_path)
                 server.chdir(destine_path)
             else:
                 log.debug("Ubicandose en ruta default")
 
             if type(filename) is list:
+                lista_archivos = []
                 for p in filename:
-                    log.debug ("Subiendo archivo: " + p)
-                    server.put(p, destine_path + "/" + os.path.basename(p))
-            else:
+                    try:
+                        lista_archivos.append(Path(p))
+                    except:
+                        raise Exception("Un de los destinos es incorrecto")
                 
-                dir_local = os.path.dirname(filename)
-                if dir_local == "":
-                    dir_local = "./"
-                log.debug("Ubicandose en ruta local: " + dir_local)
-                filename_local_comodin = os.path.basename(filename)
-                dir_list = os.listdir(dir_local)
-                log.debug ("Lista Local: "+ str(dir_list))
+                for i in lista_archivos:
+                    log.debug ("Subiendo archivo: " + str(i))
+                    server.put(i, destine_path / i.name)
+            else:
+                try:
+                    filename = Path(filename)
+                except:
+                    raise Exception("Origen incorrecto")
 
+                dir_local = filename.parent
+                
+                log.debug("Ubicandose en ruta local: " + str(dir_local))
+                
                 flag_exists = False
-                log.debug("Buscando coincidencias con: " + filename_local_comodin)
+                log.debug("Buscando coincidencias con: " + filename.name)
 
-                for file in dir_list:
+                for file in dir_local.iterdir():
 
-                    if fnmatch.fnmatch(file, filename_local_comodin):
+                    if fnmatch.fnmatch(file, filename.name):
                         flag_exists = True
-                        filename_local = os.path.join(dir_local, file)
-                        log.debug ("Subiendo archivo: " + filename_local)
-                        server.put(filename_local, destine_path + "/" + file)
+                        filename_local = dir_local / file
+                        log.debug ("Subiendo archivo: " + str(filename_local))
+                        server.put(filename_local, destine_path / file)
                 
                 if not flag_exists:
-                    raise Exception("No se encontró coincidencias para: " + filename)
+                    raise Exception("No se encontró coincidencias para: " + 
+                                    str(filename))
 
-def makedir_sftp(sftp_path="", credentials={}, recursive = False, mode=755):
+def makedir_sftp(sftp_path:StrOrPath, 
+                 credentials={}, 
+                 recursive = False, 
+                 mode=755):
     """Funcion que crea directorios en un SFTP
 
     Args:
-        sftp_path (str, optional): Ruta remoto a crear. Defaults to "".
-        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
+        sftp_path (StrOrPath): Ruta remoto a crear.
+        credentials (dict): Diccionario con credenciales. Defaults to {}.
         recursive (bool, optional): Flag que permite crear directorios
                                     recursivamente. Defaults to False.
         mode (int, optional): Permisos de directorio. Defaults to 755.
@@ -158,8 +182,13 @@ def makedir_sftp(sftp_path="", credentials={}, recursive = False, mode=755):
         transport.connect(username=credentials["username"], password=credentials["password"])
         with paramiko.SFTPClient.from_transport(transport) as server:
             server.get_channel().settimeout(100000.0)
+            
+            try:
+                sftp_path = PurePosixPath(sftp_path)
+            except:
+                raise Exception("Directorio definido erroneo.")
 
-            log.info("Inicio creacion directorio:" + sftp_path)
+            log.info("Inicio creacion directorio:" + str(sftp_path))
 
             if recursive:
 
@@ -170,7 +199,7 @@ def makedir_sftp(sftp_path="", credentials={}, recursive = False, mode=755):
                 ini = 0
                 ini_dir = ""
 
-                if sftp_path[0:1] == "/":
+                if str(sftp_path)[0:1] == "/":
                     log.info("Trabajando con directorio absoluto '/' ")
                     ini = 1
                     ini_dir = "/"
@@ -201,18 +230,23 @@ def makedir_sftp(sftp_path="", credentials={}, recursive = False, mode=755):
                     pass
 
                 if not exists:
-                    log.info("Creando directorio no recursivo:" + sftp_path)
+                    log.info("Creando directorio no recursivo:" + 
+                             str(sftp_path))
                     server.mkdir(sftp_path, mode)
                 else:
-                    log.info("Directorio no recursivo ya existe:" + sftp_path)
+                    log.info("Directorio no recursivo ya existe:" + 
+                             str(sftp_path))
 
-def list_sftp(sftp_path="", credentials={}, attr=False):
+def list_sftp(sftp_path:StrOrPath, 
+              credentials={}, 
+              attr=False):
     """Funcion que lista archivos de un SFTP
 
     Args:
-        sftp_path (str, optional): Ruta remoto a listar. Defaults to "".
-        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
-        attr (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
+        sftp_path (StrOrPath): Ruta remoto a listar.
+        credentials (dict, optional): Diccionario credenciales. Defaults to {}.
+        attr (bool, optional): Flag que permite borrar el archivo origen.
+                               Defaults to False.
 
     Returns:
         list: Lista de archivos y directorios encontrado
@@ -237,6 +271,11 @@ def list_sftp(sftp_path="", credentials={}, attr=False):
         with paramiko.SFTPClient.from_transport(transport) as server:
             server.get_channel().settimeout(100000.0)
 
+            try:
+                sftp_path = PurePosixPath(sftp_path)
+            except:
+                raise Exception("Ruta origen erronea.")
+            
             server.chdir(sftp_path)
             if attr:
                 filelist = server.listdir_attr()
@@ -244,13 +283,16 @@ def list_sftp(sftp_path="", credentials={}, attr=False):
                 filelist = server.listdir()
             return filelist
 
-def remove_sftp(list_files_sftp=[], credentials={}, attr=False):
+def remove_sftp(list_files_sftp:StrOrPathList, 
+                credentials={}, 
+                attr=False):
     """Funcion que borra archivos de un SFTP
     
     Args:
-        list_files_sftp (list, optional): Lista de archivos a borrar. Defaults to "".
-        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
-        attr (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
+        list_files_sftp (StrOrPathList): Lista de archivos a borrar.
+        credentials (dict, optional): Diccionario credenciales. Defaults to {}.
+        attr (bool, optional): Flag que permite borrar el archivo origen.
+                               Defaults to False.
     """
     
     import paramiko
@@ -279,22 +321,23 @@ def remove_sftp(list_files_sftp=[], credentials={}, attr=False):
                     log.info(str(e))
                     log.info("Ocurrio un error al borrar el archivo: " + file)
     
-def download_file_sftp(filename="", destine_path="", credentials={}, flag_remove = False):
+def download_file_sftp(filename:StrOrPathList, 
+                       destine_path:StrOrPath, 
+                       credentials={}, 
+                       flag_remove=False):
     """Funcion que descargar archivos de un SFTP
 
     Args:
-        filename (str, optional): Nombre de archivo(acepta comodines unix * ?) o lista de archivos. Defaults to "".
-        destine_path (str, optional): Prefijo de archivo a descargar. Defaults to "".
-        downloadPath (str, optional): Ruta destino remoto. Defaults to "".
-        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
-        flag_remove (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
+        filename (StrOrPathList): Nombre de archivo(acepta comodines unix * ?) 
+                                  o lista de archivos.
+        destine_path (StrOrPath): Ruta destino donde se hara la descarga.
+        credentials (dict, optional): Diccionario credenciales. Defaults to {}.
+        flag_remove (bool, optional): Flag que permite borrar el archivo 
+                                      origen. Defaults to False.
     """
 
     import paramiko
     
-    if not os.path.exists(destine_path):
-        raise Exception("Directorio destino no existe: " + destine_path)
-    
     puerto = 22
     try: puerto = credentials["port"]
     except: pass
@@ -311,62 +354,83 @@ def download_file_sftp(filename="", destine_path="", credentials={}, flag_remove
         with paramiko.SFTPClient.from_transport(transport) as server:
             #server.get_channel().settimeout(100000.0)
 
+            try:
+                destine_path = Path(destine_path)
+            except:
+                raise Exception("Destino erroneo.")
+            
             if type(filename) is list:
-                for file in filename:
+                lista_archivos = []
+                for i in filename:
+                    try:
+                        lista_archivos.append(PurePosixPath(i))
+                    except:
+                        raise Exception("Origen erroneo.")
+                
+                for file in lista_archivos:
                     
-                    dir_remoto = os.path.dirname(file)
-                    filename_remoto = os.path.basename(file)
-                    log.debug("Ubicandose en ruta: " + dir_remoto)
+                    dir_remoto = PurePosixPath(file).parent
+                    
+                    log.debug("Ubicandose en ruta: " + str(dir_remoto))
                     server.chdir(dir_remoto)
                     
-                    destine = os.path.join(destine_path, filename_remoto)
-                    log.debug("Obteniendo archivo: " + file)
-                    log.debug ("Ruta Destino: " + destine)
+                    destine = destine_path / str(file.name)
+                    log.debug("Obteniendo archivo: " + str(PurePosixPath(file)))
+                    log.debug("Ruta Destino: " + str(destine))
                     
-                    server.get( file, destine )
+                    server.get( PurePosixPath(file), destine )
                     
                     if flag_remove:
-                        server.remove(file)
+                        server.remove(PurePosixPath(file))
             else:
-
-                dir_remoto = os.path.dirname(filename)
-                filename_remoto_comodin = os.path.basename(filename)
-                log.debug("Ubicandose en ruta: " + dir_remoto)
-
+                
+                try:
+                    filename = PurePosixPath(filename)
+                except:
+                    raise Exception("Origen erroneo.")
+                
+                dir_remoto = filename.parent
+                
+                log.debug("Ubicandose en ruta: " + str(dir_remoto))
                 server.chdir(dir_remoto)
                 dir_list = server.listdir()
-                log.debug ("Lista SFTP: "+ str(dir_list))
-            
+                
+                log.debug("Lista SFTP: "+ str(dir_list))
                 
                 log.debug("Buscando coincidencias con: " +
-                          filename_remoto_comodin)
+                          filename.name)
 
                 flag_exists = False
                 
                 for file in dir_list:
                     
-                    if fnmatch.fnmatch(file, filename_remoto_comodin):
+                    if fnmatch.fnmatch(file, filename.name):
                         flag_exists = True
-                        filename_remoto = os.path.join(dir_remoto, file)
-                        log.debug ("Obteniendo archivo: " + filename_remoto)
+                        filename_remoto = dir_remoto / file
+                        log.debug("Obteniendo archivo: " + str(filename_remoto))
 
-                        log.debug ("Ruta Destino: " + destine_path)
-                        destine = os.path.join(destine_path, file)
-                        server.get( file, destine )
+                        log.debug("Ruta Destino: " + destine_path)
+                        destine = destine_path / file
+                        server.get(file, destine)
                         
                         if flag_remove:
                             server.remove(filename)
                             
                 if not flag_exists:
-                    raise Exception("No se encontró coincidencias para: " + filename)
+                    raise Exception("No se encontró coincidencias para: " + 
+                                    str(filename))
     
-def download_by_prefix_sftp(sftpPath="", prefix="", downloadPath="", credentials={}, flag_remove = False):
+def download_by_prefix_sftp(sftpPath:StrOrPath,
+                            prefix="",
+                            downloadPath:StrOrPath="",
+                            credentials={}, 
+                            flag_remove = False):
     """Funcion que descarga archivos de un SFTP basado en prefijos
 
     Args:
-        sftpPath (str, optional): Path origen del sftp. Defaults to "".
+        sftpPath (StrOrPath): Path origen del sftp.
         prefix (str, optional): Prefijo de archivo a descargar. Defaults to "".
-        downloadPath (str, optional): Path destino. Defaults to "".
+        downloadPath (StrOrPath, optional): Path destino. Defaults to "".
         credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
         flag_remove (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
     """
@@ -389,42 +453,48 @@ def download_by_prefix_sftp(sftpPath="", prefix="", downloadPath="", credentials
         with paramiko.SFTPClient.from_transport(transport) as server:
             server.get_channel().settimeout(100000.0)
 
+            try:
+                sftpPath = PurePosixPath(sftpPath)
+            except:
+                raise Exception("Origen erroneo")
+            
+            try:
+                downloadPath = Path(downloadPath)
+            except:
+                raise Exception("Destino erroneo")
+            
             server.chdir(sftpPath)
             filelist = server.listdir()
             log.debug ("Lista SFTP: "+ str(len(filelist)))
-            #print(filelist)
+            
             for filename in filelist:
-                path_file=os.path.join(downloadPath, filename)
-                exists = prefix in filename
-                if exists:
-                    log.debug ("Obteniendo archivo: " + sftpPath + filename)
-                    log.debug ("Ruta Destino: " + downloadPath + filename)
-                    server.get(filename,path_file)
+                path_file = downloadPath / filename
+                
+                if prefix in filename:
+                    log.debug("Obteniendo archivo: " + str(sftpPath / filename))
+                    log.debug("Ruta Destino: " + str(path_file))
+                    server.get(filename, path_file)
 
                     if flag_remove:
-                        if os.path.exists(path_file ):
+                        if path_file.exists:
                             server.remove(filename)
                         else:
-                            logging.error ("Ocurrio un error al obtener el archivo: " + path_file)
+                            log.error("Ocurrio un error al obtener archivo: " +
+                                      str(path_file))
                             continue
-    
-    return
 
-def move_sftp(filenames={}, credentials={}):
+def move_sftp(filenames:dict, 
+              credentials={}):
     """Funcion que renombra un archivo en SFTP
 
     Args:
-        filenames (dict, optional): Key archivo original y Value archivo destino. Defaults to {}.
-        credentials (dict, optional): Diccionario con credenciales del SFTP. Defaults to {}.
+        filenames (dict): Key archivo original y Value archivo destino.
+        credentials (dict, optional): Diccionario credenciales. Defaults to {}.
 
     Raises:
         Exception: Generado al fallar 
     """
-    #""" 
-    #:param filenames: Dictionario tipo 'Archivo original':'Archivo renombrado' (rutas absolutas)
-    #:param credentials: Credenciales de conexion al SFTP
-    #:return: None
-    #"""
+    
     import paramiko
 
     puerto = 22
@@ -443,19 +513,20 @@ def move_sftp(filenames={}, credentials={}):
         with paramiko.SFTPClient.from_transport(transport) as server:
             server.get_channel().settimeout(100000.0)
 
-            if not type(filenames) is dict:
-                raise Exception("Filename is not dict")
+            if type(filenames) is not dict:
+                raise Exception("No se recibio diccionario de datos.")
+            
+            pendientes = {}
             
             for origin, destine in filenames.items():
-                log.debug("Moviendo: " + origin + " hacia " + destine)
-                server.rename(origin,destine)
-
-def get_info_pdf(file):
-    import fitz
-    doc = fitz.open(file)
-    page_count = doc.pageCount
-    p = doc.loadPage(0)       
-    return p.getText()
+                try:
+                    pendientes[PurePosixPath(origin)] = PurePosixPath(destine)
+                except:
+                    raise Exception("Rutas ingresadas estan erroneas.")
+                
+            for origin, destine in pendientes.items():
+                log.debug("Moviendo: " + str(origin) + " hacia " + str(destine))
+                server.rename(origin, destine)
 
 def send_mail_by_exe(credentials={}, mail={}):
     """Funcion que permite ejecutar envio de correo a traves de un ejecutable inhouse.
@@ -628,13 +699,15 @@ def get_now_format(format = "%Y%m%d%H%M%S%f"):
     """Funcion que devuelve la fecha actual bajo un formato."""
     return str(datetime.now().strftime(format))
 
-def replace_string_in_file(filename_in="", filename_out="", dict_words={}):
+def replace_string_in_file(filename_in:StrOrPath, 
+                           filename_out:StrOrPath, 
+                           dict_words):
     """Funcion que eemplaza cadenas de un archivo
 
     Args:
-        filename_in (str, optional): Archivo entrada. Defaults to "".
-        filename_out (str, optional): Archivo salida. Defaults to "".
-        dict_words (dict, optional): Diccionario de palabras y valores a reemplazar. Defaults to {}.
+        filename_in (StrOrPath): Archivo entrada.
+        filename_out (StrOrPath): Archivo salida.
+        dict_words (dict): Diccionario de palabras y valores a reemplazar.
     """
 
     write_obj = open(filename_out, 'w')
@@ -652,15 +725,23 @@ def replace_string_in_file(filename_in="", filename_out="", dict_words={}):
 
     write_obj.close()
 
-def sqlcmd(file_sql, credentials, file_sql_log, dict_variable = {}, validate_error = True, coding = "65001"):
+def sqlcmd(file_sql:StrOrPath, 
+           credentials, 
+           file_sql_log:StrOrPath,
+           dict_variable={},
+           validate_error=True,
+           coding = "65001"):
     """Funcion que ejecuta el utilitario SQLCMD de SQLServer en linea de comandos
 
     Args:
-        file_sql (str): Archivo SQL
-        credentials (dict): Diccionario con crediales SQL
-        file_sql_log (str): Archivo prefijo para generar archivo log (file_sql_log + ".ahora.db")
-        dict_variable (dict, optional): Diccionario de variables a reemplazar. Defaults to {}.
-        validate_error (bool, optional): Flag para generar exception si se encuentra la palabra error. Defaults to True.
+        file_sql (StrOrPath): Archivo SQL
+        credentials (dict): Diccionario con credenciales SQL
+        file_sql_log (StrOrPath): Archivo prefijo para generar archivo log.
+        dict_variable (dict, optional): Diccionario de variables a reemplazar. 
+                                        Defaults to {}.
+        validate_error (bool, optional): Flag para generar exception si se 
+                                         encuentra la palabra error. 
+                                         Defaults to True.
         coding (str, optional): Coding de respuesta. Defaults to "65001".
 
     Raises:
@@ -675,25 +756,25 @@ def sqlcmd(file_sql, credentials, file_sql_log, dict_variable = {}, validate_err
     if os.name == 'nt':
         sqlcmd_bin = 'sqlcmd'
     
-    if not os.path.exists(file_sql):
-        raise FileNotFoundError(file_sql)
-
-    if file_sql_log == "":
-        raise Exception("Se necesita ingresar archivo log")
+    file_sql = Path(file_sql)
+    file_sql_log = Path(file_sql_log)
     
-    file_sql_tmp = file_sql + ".tmp"
+    if not file_sql.exists():
+        raise FileNotFoundError(file_sql)
+    
+    file_sql_tmp = Path(str(file_sql) + ".tmp")
 
     if len(dict_variable) > 0:
-        if os.path.exists(file_sql_tmp):
-            os.remove(file_sql_tmp)
-        replace_string_in_file( file_sql, file_sql_tmp, dict_variable)
+        if file_sql_tmp.exists():
+            file_sql_tmp.unlink()
+        replace_string_in_file(file_sql, file_sql_tmp, dict_variable)
     else:
         shutil.copy(file_sql, file_sql_tmp)
     
     
     cmd = (sqlcmd_bin + ' -e -y 0'  + 
-                        ' -i ' + file_sql_tmp            +
-                        ' -o ' + file_sql_log            +
+                        ' -i ' + str(file_sql_tmp)       +
+                        ' -o ' + str(file_sql_log)       +
                         ' -S ' + credentials['hostname'] +
                         ' -d ' + credentials['database'] + 
                         ' -U ' + credentials['username'] +
@@ -716,18 +797,27 @@ def sqlcmd(file_sql, credentials, file_sql_log, dict_variable = {}, validate_err
         if str_line != "":
             log.debug(str_line)
     
-    os.remove(file_sql_tmp)
+    file_sql_tmp.unlink()
 
-    if os.path.exists(file_sql_log):
-        log.debug( open(file_sql_log, "r", encoding='utf-8', errors='ignore').read() )
+    if file_sql_log.exists():
+        log.debug(open(file_sql_log, 
+                       "r", 
+                       encoding='utf-8', 
+                       errors='ignore').read())
     
         if validate_error:
             if check_if_string_in_file(file_sql_log, "error"):
-                raise Exception("Se encontro un error en el archivo log de la BD.")
+                raise Exception("Se encontro un error en el archivo log.")
     else:
         raise Exception("Archivo output sqlcmd no generado.")
 
-def bcp(table, file, operation, credentials, file_sql_log, validate_error = True, coding = "-C 65001"):
+def bcp(table, 
+        file:StrOrPath, 
+        operation, 
+        credentials, 
+        file_sql_log:StrOrPath, 
+        validate_error=True, 
+        coding="-C 65001"):
     """Funcion que ejecuta el utilitario BCP de SQLServer en linea de comandos
 
     Args:
@@ -750,20 +840,21 @@ def bcp(table, file, operation, credentials, file_sql_log, validate_error = True
     if os.name == 'nt':
         bcpcmd_bin = 'bcp'
     
-    if file_sql_log == "":
-        raise Exception("Se necesita ingresar archivo log")
+    file = Path(file)
+    file_sql_log = Path(file_sql_log)
     
     if not operation in ("IN","OUT"):
         raise Exception("Operacion BCP no permitida")
 
-    cmd = (bcpcmd_bin + ' ' + table + ' ' + operation + ' "' + file + '"' + 
-                ' -e ' + file_sql_log            +
-                ' -S ' + credentials['hostname'] +
-                ' -d ' + credentials['database'] + 
-                ' -U ' + credentials['username'] +
-                ' -P ' + credentials['password'] +
-                ' -c ' + coding +
-                ' -b1000 -m1000 -t"|"' )
+    cmd = (bcpcmd_bin + ' ' + table + ' ' + 
+           operation + ' "' + str(file) + '"' + 
+           ' -e ' + str(file_sql_log)       +
+           ' -S ' + credentials['hostname'] +
+           ' -d ' + credentials['database'] + 
+           ' -U ' + credentials['username'] +
+           ' -P ' + credentials['password'] +
+           ' -c ' + coding +
+           ' -b1000 -m1000 -t"|"' )
     
     log.debug("Ejecutando sql")
     log.debug(cmd)
@@ -781,16 +872,18 @@ def bcp(table, file, operation, credentials, file_sql_log, validate_error = True
         if str_line != "":
             log.debug(str_line)
 
-    if os.path.exists(file_sql_log):
+    if file_sql_log.exists():
         log.debug( open(file_sql_log, "r", encoding='utf-8').read() )
     
         if validate_error:
             if check_if_string_in_file(file_sql_log, "error"):
-                raise Exception("Se encontro un error en el archivo log de la BD.")
+                raise Exception("Se encontro un error en el archivo log")
     else:
         raise Exception("Archivo output bcp no generado.")
 
-def get_data_from_sqllog(file_sql_log, file_result, prefix = "DATA:"):
+def get_data_from_sqllog(file_sql_log:StrOrPath, 
+                         file_result:StrOrPath, 
+                         prefix = "DATA:"):
     """Funcion que filtra las lineas de texto que comiencen con el prefijo
 
     Args:
@@ -802,7 +895,10 @@ def get_data_from_sqllog(file_sql_log, file_result, prefix = "DATA:"):
         FileNotFoundError: Archivo de entrada no encontrado
     """
     
-    if not os.path.exists(file_sql_log):
+    file_sql_log = Path(file_sql_log)
+    file_result = Path(file_result)
+                         
+    if not file_sql_log.exists():
         raise FileNotFoundError(file_sql_log)
     
     file_out = open(file_result, "w", encoding='utf-8')
